@@ -4,5 +4,7 @@
 //! in the retrieval of data from the [PokeAPI](https://pokeapi.co/).
 
 mod get_pokemon;
-
 pub use get_pokemon::get_pokemon;
+
+mod get_ability;
+pub use get_ability::get_ability;
